==> jc-1.4.0.tar.gz: soot/coffi/Info.h <==
// class soot.coffi.Info

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f8a8c6220052c3ec soot_coffi_Info

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_coffi_Info_H_
#define _JC_soot_coffi_Info_H_

// Forward structure declarations
struct _jc_java_io_PrintStream$object;
struct _jc_java_lang_Class$object;
struct _jc_soot_coffi_ClassFile$object;

// Typedefs
typedef struct _jc_soot_coffi_Info$sub_refs	_jc_soot_coffi_Info$sub_refs;
typedef struct _jc_soot_coffi_Info$sub_nonrefs	_jc_soot_coffi_Info$sub_nonrefs;
typedef struct _jc_soot_coffi_Info$refs	_jc_soot_coffi_Info$refs;
typedef struct _jc_soot_coffi_Info$nonrefs	_jc_soot_coffi_Info$nonrefs;
typedef struct _jc_soot_coffi_Info$object	_jc_soot_coffi_Info$object;

typedef const struct _jc_soot_coffi_Info$vmethods	_jc_soot_coffi_Info$vmethods;
typedef const struct _jc_soot_coffi_Info$vtable	_jc_soot_coffi_Info$vtable;
typedef const struct _jc_soot_coffi_Info$vtype	_jc_soot_coffi_Info$vtype;

// Constructors
extern void _jc_soot_coffi_Info$method$_init$73661ea2b7321bd1(_jc_env *, struct _jc_soot_coffi_Info$object *, struct _jc_soot_coffi_ClassFile$object *);

// Virtual methods
extern void _jc_soot_coffi_Info$method$verboseReport$183398abd49fb3c7(_jc_env *, struct _jc_soot_coffi_Info$object *, struct _jc_java_io_PrintStream$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Info$method_info$verboseReport$183398abd49fb3c7;

// Virtual methods structure
struct _jc_soot_coffi_Info$vmethods {
	void	(*verboseReport$183398abd49fb3c7)(_jc_env *, struct _jc_soot_coffi_Info$object *, struct _jc_java_io_PrintStream$object *);
};

// Vtable
struct _jc_soot_coffi_Info$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Info$vmethods	soot_coffi_Info;
};

// Vtype
struct _jc_soot_coffi_Info$vtype {
	_jc_type			type;
	_jc_soot_coffi_Info$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Info$sub_refs {
	struct _jc_soot_coffi_ClassFile$object	*cf;
};

// Reference instance fields (object)
struct _jc_soot_coffi_Info$refs {
    _jc_soot_coffi_Info$sub_refs	soot_coffi_Info;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Info$sub_nonrefs {
	jlong	flength;
	jint	cp;
	jint	fields;
	jint	methods;
	jint	pfields;
	jint	pmethods;
	jint	attribsave;
	jint	attribcpsave;
	jint	psave;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Info$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Info$sub_nonrefs	soot_coffi_Info;
};

// Object instance structure
struct _jc_soot_coffi_Info$object {
	_jc_soot_coffi_Info$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Info$vtype	*vtype;
	_jc_soot_coffi_Info$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Info$vtype _jc_soot_coffi_Info$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Info, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Info$class_object;

#endif	/* _JC_soot_coffi_Info_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Info.h <==
// class soot.coffi.Info

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f8a8c6220052c3ec soot_coffi_Info

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_coffi_Info_H_
#define _JC_soot_coffi_Info_H_

// Forward structure declarations
struct _jc_java_io_PrintStream$object;
struct _jc_java_lang_Class$object;
struct _jc_soot_coffi_ClassFile$object;

// Typedefs
typedef struct _jc_soot_coffi_Info$sub_refs	_jc_soot_coffi_Info$sub_refs;
typedef struct _jc_soot_coffi_Info$sub_nonrefs	_jc_soot_coffi_Info$sub_nonrefs;
typedef struct _jc_soot_coffi_Info$refs	_jc_soot_coffi_Info$refs;
typedef struct _jc_soot_coffi_Info$nonrefs	_jc_soot_coffi_Info$nonrefs;
typedef struct _jc_soot_coffi_Info$object	_jc_soot_coffi_Info$object;

typedef const struct _jc_soot_coffi_Info$vmethods	_jc_soot_coffi_Info$vmethods;
typedef const struct _jc_soot_coffi_Info$vtable	_jc_soot_coffi_Info$vtable;
typedef const struct _jc_soot_coffi_Info$vtype	_jc_soot_coffi_Info$vtype;

// Constructors
extern void _jc_soot_coffi_Info$method$_init$73661ea2b7321bd1(_jc_env *, struct _jc_soot_coffi_Info$object *, struct _jc_soot_coffi_ClassFile$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_coffi_Info$method$verboseReport$183398abd49fb3c7(_jc_env *, struct _jc_soot_coffi_Info$object *, struct _jc_java_io_PrintStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Info$method_info$verboseReport$183398abd49fb3c7;

// Virtual methods structure
struct _jc_soot_coffi_Info$vmethods {
	void	(*verboseReport$183398abd49fb3c7)(_jc_env *, struct _jc_soot_coffi_Info$object *, struct _jc_java_io_PrintStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_coffi_Info$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Info$vmethods	soot_coffi_Info;
};

// Vtype
struct _jc_soot_coffi_Info$vtype {
	_jc_type			type;
	_jc_soot_coffi_Info$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Info$sub_refs {
	struct _jc_soot_coffi_ClassFile$object	*cf;
};

// Reference instance fields (object)
struct _jc_soot_coffi_Info$refs {
    _jc_soot_coffi_Info$sub_refs	soot_coffi_Info;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Info$sub_nonrefs {
	jlong	flength;
	jint	cp;
	jint	fields;
	jint	methods;
	jint	pfields;
	jint	pmethods;
	jint	attribsave;
	jint	attribcpsave;
	jint	psave;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Info$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Info$sub_nonrefs	soot_coffi_Info;
};

// Object instance structure
struct _jc_soot_coffi_Info$object {
	_jc_soot_coffi_Info$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Info$vtype	*vtype;
	_jc_soot_coffi_Info$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Info$vtype _jc_soot_coffi_Info$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Info, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Info$class_object;

#endif	/* _JC_soot_coffi_Info_H_ */
